RuutConversation class

Annotations
  • @JsonSerializable.new(explicitToJson: true)
  • @HiveType.new(typeId: CHATWOOT_CONVERSATION_HIVE_TYPE_ID)

Constructors

RuutConversation({required int id, required int inboxId, required List<RuutMessage> messages, required RuutContact contact})
RuutConversation.fromJson(Map<String, dynamic> json)
factory

Properties

contact → RuutContact
Contact of the conversation
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
The numeric ID of the conversation
final
inboxId → int
The numeric ID of the inbox
final
messages → List<RuutMessage>
List of all messages from the conversation
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited