RuutMessage class FlutterClientSdk

Annotations
  • @JsonSerializable.new(explicitToJson: true)
  • @HiveType.new(typeId: CHATWOOT_MESSAGE_HIVE_TYPE_ID)

Constructors

RuutMessage({required int id, required String? content, required int? messageType, required String? contentType, required dynamic contentAttributes, required String createdAt, required int? conversationId, required List? attachments, required RuutEventMessageUser? sender})
RuutMessage.fromJson(Map<String, dynamic> json)
factory

Properties

attachments → List?
list of media/doc/file attachment for message
final
content → String?
text content of the message
final
contentAttributes → dynamic
final
contentType → String?
content type of message
final
conversationId → int?
id of the conversation the message belongs to
final
createdAt → String
date and time message was created
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
unique identifier of the message
final
isMine → bool
checks if message belongs to contact making the request
no setter
messageType → int?
type of message
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender → RuutEventMessageUser?
The user this message belongs to
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited