RuutUser class

Annotations
  • @JsonSerializable.new(explicitToJson: true)
  • @HiveType.new(typeId: CHATWOOT_USER_HIVE_TYPE_ID)

Constructors

RuutUser({String? identifier, String? identifierHash, String? name, String? email, String? avatarUrl, dynamic customAttributes})
RuutUser.fromJson(Map<String, dynamic> json)
factory

Properties

avatarUrl → String?
profile picture url of user
final
customAttributes → dynamic
any other custom attributes to be linked to the user
final
email → String?
email of ruut user
final
hashCode → int
The hash code for this object.
no setterinherited
identifier → String?
custom ruut user identifier
final
identifierHash → String?
custom user identifier hash
final
name → String?
name of ruut user
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited