LocalStorage class

Constructors

LocalStorage({required RuutUserDao userDao, required RuutConversationDao conversationDao, required RuutContactDao contactDao, required RuutMessagesDao messagesDao})

Properties

contactDao ↔ RuutContactDao
getter/setter pair
conversationDao ↔ RuutConversationDao
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
messagesDao ↔ RuutMessagesDao
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userDao ↔ RuutUserDao
getter/setter pair

Methods

clear({bool clearRuutUserStorage = true}) → Future<void>
clearAll() → Future<void>
dispose() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

openDB({void onInitializeHive()?}) → Future<void>