RuutNewMessageRequest class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

RuutNewMessageRequest({required String content, required String echoId})
RuutNewMessageRequest.fromJson(Map<String, dynamic> json)
factory

Properties

content → String
final
echoId → String
final
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited