RuutEventMessageData class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

RuutEventMessageData({int? id, RuutEventMessageUser? user, dynamic conversation, String? echoId, RuutEventMessageUser? sender, int? conversationId, dynamic createdAt, dynamic contentAttributes, String? contentType, int? messageType, String? content, int? inboxId, String? sourceId, dynamic updatedAt, String? status, int? accountId, dynamic externalSourceIds, bool? private, int? senderId, dynamic users})
RuutEventMessageData.fromJson(Map<String, dynamic> json)
factory

Properties

accountId → int?
final
content → String?
final
contentAttributes → dynamic
final
contentType → String?
final
conversation → dynamic
final
conversationId → int?
final
createdAt → dynamic
final
echoId → String?
final
externalSourceIds → dynamic
final
hashCode → int
The hash code for this object.
no setterinherited
id → int?
final
inboxId → int?
final
messageType → int?
final
private → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender → RuutEventMessageUser?
final
senderId → int?
final
sourceId → String?
final
status → String?
final
updatedAt → dynamic
final
user → RuutEventMessageUser?
final
users → dynamic
final

Methods

getMessage() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited