RuutClientService class abstract

Service for handling ruut api calls See RuutClientServiceImpl

Implementers

Constructors

RuutClientService(String _baseUrl, Dio _dio)

Properties

connection ↔ WebSocketChannel?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createMessage(RuutNewMessageRequest request) → Future<RuutMessage>
createMessageAttachment(File file) → Future<RuutMessage>
getAllMessages() → Future<List<RuutMessage>>
getContact() → Future<RuutContact>
getConversations() → Future<List<RuutConversation>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendAction(String contactPubsubToken, RuutActionType action) → void
startWebSocketConnection(String contactPubsubToken, {WebSocketChannel onStartConnection(Uri)?}) → void
toString() → String
A string representation of this object.
inherited
updateContact(dynamic update) → Future<RuutContact>
updateMessage(String messageIdentifier, dynamic update) → Future<RuutMessage>

Operators

operator ==(Object other) → bool
The equality operator.
inherited