RuutClientServiceImpl class

Inheritance

Constructors

RuutClientServiceImpl(String baseUrl, {required Dio dio})

Properties

connection ↔ WebSocketChannel?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createMessage(RuutNewMessageRequest request) → Future<RuutMessage>
Sends message to ruut inbox
override
createMessageAttachment(File file) → Future<RuutMessage>
override
getAllMessages() → Future<List<RuutMessage>>
Gets all messages of current ruut client instance's conversation
override
getContact() → Future<RuutContact>
Gets contact of current ruut client instance
override
getConversations() → Future<List<RuutConversation>>
Gets all conversation of current ruut client instance
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendAction(String contactPubsubToken, RuutActionType actionType) → void
override
startWebSocketConnection(String contactPubsubToken, {WebSocketChannel onStartConnection(Uri)?}) → void
override
toString() → String
A string representation of this object.
inherited
updateContact(dynamic update) → Future<RuutContact>
Update current client instance's contact
override
updateMessage(String messageIdentifier, dynamic update) → Future<RuutMessage>
Update message with id messageIdentifier with contents of update
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited