RuutChatView class FlutterClientSdk

Ruut chat widget

Inheritance

Constructors

RuutChatView({Key? key, required String inboxIdentifier, bool enablePersistence = true, RuutUser? user, PreferredSizeWidget? appBar, Future<void> onEndReached()?, double? onEndReachedThreshold, void onMessageLongPress(Message)?, void onMessageTap(Message)?, void onSendPressed(Message)?, void onTextChanged(String)?, bool showUserAvatars = true, bool showUserNames = true, RuutChatTheme theme = const RuutChatTheme(), RuutChatL10n l10n = const RuutChatL10n(), DateFormat? timeFormat, DateFormat? dateFormat, void onWelcome()?, void onPing()?, void onConfirmedSubscription()?, void onMessageReceived(RuutMessage)?, void onMessageSent(RuutMessage)?, void onMessageDelivered(RuutMessage)?, void onMessageUpdated(RuutMessage)?, void onPersistedMessagesRetrieved(List<RuutMessage>)?, void onMessagesRetrieved(List<RuutMessage>)?, void onConversationStartedTyping()?, void onConversationStoppedTyping()?, void onConversationIsOnline()?, void onConversationIsOffline()?, void onError(RuutClientException)?, bool isPresentedInDialog = false, void onMessageRead(RuutMessage)?})
const

Properties

appBar → PreferredSizeWidget?
Specifies a custom app bar for ruut page widget
final
dateFormat → DateFormat?
See Chat.dateFormat
final
enablePersistence → bool
Enables persistence of ruut client instance's contact, conversation and messages to disk for convenience.
final
hashCode → int
The hash code for this object.
no setterinherited
inboxIdentifier → String
Identifier for target ruut inbox.
final
isPresentedInDialog → bool
Horizontal padding is reduced if set to true
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
l10n → RuutChatL10n
See RuutChatL10n
final
onConfirmedSubscription → void Function()?
See RuutCallbacks.onConfirmedSubscription
final
onConversationIsOffline → void Function()?
See RuutCallbacks.onConversationIsOffline
final
onConversationIsOnline → void Function()?
See RuutCallbacks.onConversationIsOnline
final
onConversationStartedTyping → void Function()?
See RuutCallbacks.onConversationStartedTyping
final
onConversationStoppedTyping → void Function()?
See RuutCallbacks.onConversationStoppedTyping
final
onEndReached → Future<void> Function()?
See ChatList.onEndReached
final
onEndReachedThreshold → double?
See ChatList.onEndReachedThreshold
final
onError → void Function(RuutClientException)?
See RuutCallbacks.onError
final
onMessageDelivered → void Function(RuutMessage)?
See RuutCallbacks.onMessageDelivered
final
onMessageLongPress → void Function(Message)?
See Message.onMessageLongPress
final
onMessageRead → void Function(RuutMessage)?
See RuutCallbacks.onMessageRead
final
onMessageReceived → void Function(RuutMessage)?
See RuutCallbacks.onMessageReceived
final
onMessageSent → void Function(RuutMessage)?
See RuutCallbacks.onMessageSent
final
onMessagesRetrieved → void Function(List<RuutMessage>)?
See RuutCallbacks.onMessagesRetrieved
final
onMessageTap → void Function(Message)?
See Message.onMessageTap
final
onMessageUpdated → void Function(RuutMessage)?
See RuutCallbacks.onMessageUpdated
final
onPersistedMessagesRetrieved → void Function(List<RuutMessage>)?
See RuutCallbacks.onPersistedMessagesRetrieved
final
onPing → void Function()?
See RuutCallbacks.onPing
final
onSendPressed → void Function(Message)?
See Input.onSendPressed
final
onTextChanged → void Function(String)?
See Input.onTextChanged
final
onWelcome → void Function()?
See RuutCallbacks.onWelcome
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showUserAvatars → bool
Show avatars for received messages.
final
showUserNames → bool
Show user names for received messages.
final
theme → RuutChatTheme
final
timeFormat → DateFormat?
See Chat.timeFormat
final
user → RuutUser?
Custom user details to be attached to ruut contact
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _RuutChatViewState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited