ColorUtils class

Constructors

ColorUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

darken(Color color, double amount) → Color
getTextColor(Color backgroundColor) → Color
Returns the appropriate text color (white or black) based on the background color
isDarkColor(Color color) → bool
Determines if the background color is dark.